pub struct ChannelMessage {
pub text: String,
pub attachments: Vec<Attachment>,
pub is_guest_context: bool,
pub is_from_bot: bool,
}Expand description
Incoming message from a channel.
Fields
text: Stringattachments: Vec<Attachment>is_guest_context: booltrue when the message originated from a Telegram guest mention (guest_message update).
is_from_bot: booltrue when the sender is a Telegram bot (from.is_bot = true).