pub struct ConfigWatcher { /* private fields */ }Implementations
Sourceimpl ConfigWatcher
impl ConfigWatcher
Sourcepub fn start(
path: &Path,
tx: Sender<ConfigEvent>,
) -> Result<Self, ConfigWatcherError>
pub fn start( path: &Path, tx: Sender<ConfigEvent>, ) -> Result<Self, ConfigWatcherError>
Start watching a config file for changes.
Watches the parent directory and filters for the target filename.
Sends ConfigEvent::Changed on any modification (debounced 500ms).
Errors
Returns an error if the filesystem watcher cannot be initialized or the config file path has no parent directory.