pub struct ProviderConfigSnapshot {
pub claude_api_key: Option<String>,
pub openai_api_key: Option<String>,
pub gemini_api_key: Option<String>,
pub compatible_api_keys: HashMap<String, String>,
pub llm_request_timeout_secs: u64,
pub embedding_model: String,
pub gonka_private_key: Option<Zeroizing<String>>,
pub gonka_address: Option<String>,
pub cocoon_access_hash: Option<String>,
}Expand description
Minimal config snapshot needed to reconstruct a provider at runtime via /provider <name>.
Secrets are stored as plain strings because Secret intentionally does not implement
Clone. They are re-wrapped in Secret when passed to build_provider_for_switch.
Clone so ACP/serve deps structs (built once per process) can hand each session its own
owned copy via Agent::with_provider_pool.
Fields
claude_api_key: Option<String>openai_api_key: Option<String>gemini_api_key: Option<String>compatible_api_keys: HashMap<String, String>llm_request_timeout_secs: u64embedding_model: Stringgonka_private_key: Option<Zeroizing<String>>gonka_address: Option<String>cocoon_access_hash: Option<String>Trait Implementations
Sourceimpl Clone for ProviderConfigSnapshot
impl Clone for ProviderConfigSnapshot
Sourcefn clone(&self) -> ProviderConfigSnapshot
fn clone(&self) -> ProviderConfigSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ProviderConfigSnapshot
impl Default for ProviderConfigSnapshot
Sourcefn default() -> ProviderConfigSnapshot
fn default() -> ProviderConfigSnapshot
Returns the “default value” for a type. Read more