pub struct LearningConfig {Show 21 fields
pub enabled: bool,
pub auto_activate: bool,
pub min_failures: u32,
pub improve_threshold: f64,
pub rollback_threshold: f64,
pub min_evaluations: u32,
pub max_versions: u32,
pub cooldown_minutes: u64,
pub correction_detection: bool,
pub correction_confidence_threshold: f32,
pub detector_mode: DetectorMode,
pub judge_model: String,
pub feedback_provider: String,
pub judge_adaptive_low: f32,
pub judge_adaptive_high: f32,
pub correction_recall_limit: u32,
pub correction_min_similarity: f32,
pub auto_promote_min_uses: u32,
pub auto_promote_threshold: f64,
pub auto_demote_min_uses: u32,
pub auto_demote_threshold: f64,
}Fields
enabled: boolauto_activate: boolmin_failures: u32improve_threshold: f64rollback_threshold: f64min_evaluations: u32max_versions: u32cooldown_minutes: u64correction_detection: boolcorrection_confidence_threshold: f32detector_mode: DetectorModeDetector strategy: “regex” (default) or “judge”.
judge_model: StringModel for the judge detector (e.g. “claude-sonnet-4-6”). Empty = use primary provider.
feedback_provider: StringProvider name from [[llm.providers]] for detector_mode = "model" (LlmClassifier).
Empty = use the primary provider. Named but not found in registry = log warning, degrade to regex-only. Never fails startup.
judge_adaptive_low: f32Regex confidence below this value is treated as “not a correction” — judge not invoked.
judge_adaptive_high: f32Regex confidence at or above this value is accepted without judge confirmation.
correction_recall_limit: u32correction_min_similarity: f32auto_promote_min_uses: u32auto_promote_threshold: f64auto_demote_min_uses: u32auto_demote_threshold: f64Trait Implementations
Sourceimpl Clone for LearningConfig
impl Clone for LearningConfig
Sourcefn clone(&self) -> LearningConfig
fn clone(&self) -> LearningConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LearningConfig
impl Debug for LearningConfig
Sourceimpl Default for LearningConfig
impl Default for LearningConfig
Sourcefn default() -> LearningConfig
fn default() -> LearningConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LearningConfig
impl<'de> Deserialize<'de> for LearningConfig
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LearningConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LearningConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for LearningConfig
impl Serialize for LearningConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more