pub trait AgentRouter: Send + Sync {
// Required method
fn route(
&self,
task: &TaskNode,
available: &[SubAgentDef],
) -> Option<String>;
}Expand description
Selects the best agent definition for a given task.
pub trait AgentRouter: Send + Sync {
// Required method
fn route(
&self,
task: &TaskNode,
available: &[SubAgentDef],
) -> Option<String>;
}Selects the best agent definition for a given task.