pub struct ContentSource {
pub kind: ContentSourceKind,
pub trust_level: TrustLevel,
pub identifier: Option<String>,
pub memory_hint: Option<MemorySourceHint>,
}Expand description
Provenance metadata attached to a piece of untrusted content.
Fields
kind: ContentSourceKindtrust_level: TrustLevelidentifier: Option<String>Optional identifier: tool name, URL, agent ID, etc.
memory_hint: Option<MemorySourceHint>Optional hint for memory retrieval sub-sources. When Some, modulates injection
detection sensitivity in ContentSanitizer::sanitize. Non-memory sources leave
this as None — full detection applies.
Implementations
Sourceimpl ContentSource
impl ContentSource
pub fn new(kind: ContentSourceKind) -> ContentSource
pub fn with_identifier(self, id: impl Into<String>) -> ContentSource
pub fn with_trust_level(self, level: TrustLevel) -> ContentSource
Sourcepub fn with_memory_hint(self, hint: MemorySourceHint) -> ContentSource
pub fn with_memory_hint(self, hint: MemorySourceHint) -> ContentSource
Attach a memory source hint to modulate injection detection sensitivity.
Only meaningful for ContentSourceKind::MemoryRetrieval sources.