pub struct ProviderConfigSnapshot {
pub claude_api_key: Option<String>,
pub openai_api_key: Option<String>,
pub gemini_api_key: Option<String>,
pub compatible_api_keys: HashMap<String, String>,
pub llm_request_timeout_secs: u64,
pub embedding_model: String,
}Expand description
Minimal config snapshot needed to reconstruct a provider at runtime via /provider <name>.
Secrets are stored as plain strings because Secret intentionally does not implement
Clone. They are re-wrapped in Secret when passed to build_provider_for_switch.
Fields
claude_api_key: Option<String>openai_api_key: Option<String>gemini_api_key: Option<String>compatible_api_keys: HashMap<String, String>llm_request_timeout_secs: u64embedding_model: StringAuto Trait Implementations
impl Freeze for ProviderConfigSnapshot
impl RefUnwindSafe for ProviderConfigSnapshot
impl Send for ProviderConfigSnapshot
impl Sync for ProviderConfigSnapshot
impl Unpin for ProviderConfigSnapshot
impl UnsafeUnpin for ProviderConfigSnapshot
impl UnwindSafe for ProviderConfigSnapshot